==> haskell-hspec-megaparsec-2.0.0-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-megaparsec
version: 2.0.0
id: hspec-megaparsec-2.0.0-6ZWgASfPXXMEH7bmeDCF5Y
key: hspec-megaparsec-2.0.0-6ZWgASfPXXMEH7bmeDCF5Y
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/hspec-megaparsec
synopsis: Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.
category: Testing, Parsing
abi: 9628e538d73049959cac1775a596b13d
exposed: True
exposed-modules:
    Test.Hspec.Megaparsec
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-megaparsec-2.0.0
hs-libraries: HShspec-megaparsec-2.0.0-6ZWgASfPXXMEH7bmeDCF5Y
depends:
    base-4.12.0.0 containers-0.6.0.1
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    megaparsec-7.0.4-LtBOPHXtadb29GI7W5CNMI
haddock-interfaces: /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-megaparsec-2.0.0-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-megaparsec
version: 2.0.0
id: hspec-megaparsec-2.0.0-GHB1G5xvKSgDJkPRNlWQOt
key: hspec-megaparsec-2.0.0-GHB1G5xvKSgDJkPRNlWQOt
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/hspec-megaparsec
synopsis: Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.
category: Testing, Parsing
abi: 521552deeacfca6c37a84cfeefea504f
exposed: True
exposed-modules:
    Test.Hspec.Megaparsec
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-megaparsec-2.0.0
hs-libraries: HShspec-megaparsec-2.0.0-GHB1G5xvKSgDJkPRNlWQOt
depends:
    base-4.12.0.0 containers-0.6.0.1
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    megaparsec-7.0.5-LbhLLsrUoh4Eo2xJp0Opc2
haddock-interfaces: /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
